==> postgis_1.5.1.orig.tar.gz: postgis-1.5.1/liblwgeom/cunit/cu_geodetic_data.h <==
int gbox_data_length = 54;
char gbox_data[][512] =
{
	"LINESTRING(-0 40,0 -30)",
	"LINESTRING(-180 90,180 -80)",
	"LINESTRING(-0 90,0 -90)",
	"LINESTRING(0 90,80 -90)",
	"LINESTRING(0 -5,0 -5)",
	"LINESTRING(180 -35,180 45)",
	"LINESTRING(158 -85,-57 86)",
	"LINESTRING(-3.083333333333333333333333333333333 9.83333333333333333333333333333333,15.5 -5.25)",
	"LINESTRING(-35.0 52.5,50.0 60.0)",
	"LINESTRING(-122.5 56.25,-123.5 69.166666)",
	"LINESTRING(-121.75 42.55,-122.35 43.25)",
	"LINESTRING(-3.083333333333333333333333333333333 9.83333333333333333333333333333333,15.5 -5.25)",
	"LINESTRING(86.85 9.85,105.5 -5.25)",
	"LINESTRING(-120.0 62.55,-120.0 62.55)",
	"LINESTRING(-135.0 40.0,45.0 -40.0)",
	"LINESTRING(-120.0 62.55,60.0 73.25)",
	"LINESTRING(-120.0 -62.55,60.0 -73.25)",
	"LINESTRING(-120.0 20.0,-120.5 20.0)",
	"LINESTRING(-120.0 45.0,-120.5 45.0)",
	"LINESTRING(-120.0 75.0,-120.5 75.0)",
	"LINESTRING(-120.0 -20.0,-120.5 -20.0)",
	"LINESTRING(-120.0 -45.0,-120.5 -45.0)",
	"LINESTRING(-120.0 -75.0,-120.5 -75.0)",
	"LINESTRING(0.0 60.0,0.0 7.0)",
	"LINESTRING(0.0 -60.0,0.0 -70.0)",
	"LINESTRING(180.0 60.0,180.0 70.0)",
	"LINESTRING(4.0 45.0,-4.0 45.0)",
	"LINESTRING(-176.0 45.0,176.0 45.0)",
	"LINESTRING(176.0 45.0,-176.0 45.0)",
	"LINESTRING(-4.0 45.0,4.0 45.0)",
	"LINESTRING(-45.0 60.0,135.0 72.0)",
	"LINESTRING(-45.0 -60.0,135.0 -72.0)",
	"LINESTRING(-15.0 3.5,15.0 -3.5)",
	"LINESTRING(75.0 3.5,105.0 -3.5)",
	"LINESTRING(-75.0 3.5,-105.0 -3.5)",
	"LINESTRING(-153.11560 24.70504,-9.15580 24.18317)",
	"LINESTRING(-178.0 45.0,165.0 45.0)",
	"LINESTRING(10.0 45.0,110.0 45.0)",
	"LINESTRING(10.0 -45.0,110.0 -45.0)",
	"LINESTRING(-10.0 45.0,-110.0 45.0)",
	"LINESTRING(160.0 25.0,-160.0 25.0)",
	"LINESTRING(170.0 35.0,-160.0 35.0)",
	"LINESTRING(-10.0 35.0,10.0 -35.0)",
	"LINESTRING(-80.0 25.0,-60.0 -25.0)",
	"LINESTRING(-80.0 25.0,-60.0 -45.0)",
	"LINESTRING(-120.0 70.0,60.0 70.0)",
	"LINESTRING(-120.0 -70.0,60.0 -70.0)",
	"LINESTRING(-112.0 45.0,-112.00166666666666666666666666667 45.0)",
	"LINESTRING(-120.0 -5.0,60.0 80.0)",
	"LINESTRING(165.0 10.0,-172.0 -5.0)",
	"LINESTRING(97.87714324162704 46.6879465040995,155.49353589912155 -68.93911854796522)",
	"LINESTRING(-77.90029319006709 -20.61989357708765,-29.776541043747443 88.24497900223159)",
	"LINESTRING(12.21419896647646 -2.2758177391540926,149.7713684095024 13.210117902931728)",
	"LINESTRING(-49.891199414628915 66.72545480471234,-39.418865490450656 -89.97504625275525)"
};

==> postgis_1.5.3.orig.tar.gz: postgis-1.5.3/liblwgeom/cunit/cu_geodetic_data.h <==
int gbox_data_length = 55;
char gbox_data[][512] =
{
	"LINESTRING(-0 40,0 -30)",
	"LINESTRING(-180 90,180 -80)",
	"LINESTRING(-0 90,0 -90)",
	"LINESTRING(0 90,80 -90)",
	"LINESTRING(0 -5,0 -5)",
	"LINESTRING(180 -35,180 45)",
	"LINESTRING(158 -85,-57 86)",
	"LINESTRING(-3.083333333333333333333333333333333 9.83333333333333333333333333333333,15.5 -5.25)",
	"LINESTRING(-35.0 52.5,50.0 60.0)",
	"LINESTRING(-122.5 56.25,-123.5 69.166666)",
	"LINESTRING(-121.75 42.55,-122.35 43.25)",
	"LINESTRING(-3.083333333333333333333333333333333 9.83333333333333333333333333333333,15.5 -5.25)",
	"LINESTRING(86.85 9.85,105.5 -5.25)",
	"LINESTRING(-120.0 62.55,-120.0 62.55)",
	"LINESTRING(-135.0 40.0,45.0 -40.0)",
	"LINESTRING(-120.0 62.55,60.0 73.25)",
	"LINESTRING(-120.0 -62.55,60.0 -73.25)",
	"LINESTRING(-120.0 20.0,-120.5 20.0)",
	"LINESTRING(-120.0 45.0,-120.5 45.0)",
	"LINESTRING(-120.0 75.0,-120.5 75.0)",
	"LINESTRING(-120.0 -20.0,-120.5 -20.0)",
	"LINESTRING(-120.0 -45.0,-120.5 -45.0)",
	"LINESTRING(-120.0 -75.0,-120.5 -75.0)",
	"LINESTRING(0.0 60.0,0.0 7.0)",
	"LINESTRING(0.0 -60.0,0.0 -70.0)",
	"LINESTRING(180.0 60.0,180.0 70.0)",
	"LINESTRING(4.0 45.0,-4.0 45.0)",
	"LINESTRING(-176.0 45.0,176.0 45.0)",
	"LINESTRING(176.0 45.0,-176.0 45.0)",
	"LINESTRING(-4.0 45.0,4.0 45.0)",
	"LINESTRING(-45.0 60.0,135.0 72.0)",
	"LINESTRING(-45.0 -60.0,135.0 -72.0)",
	"LINESTRING(-15.0 3.5,15.0 -3.5)",
	"LINESTRING(75.0 3.5,105.0 -3.5)",
	"LINESTRING(-75.0 3.5,-105.0 -3.5)",
	"LINESTRING(-153.11560 24.70504,-9.15580 24.18317)",
	"LINESTRING(-178.0 45.0,165.0 45.0)",
	"LINESTRING(10.0 45.0,110.0 45.0)",
	"LINESTRING(10.0 -45.0,110.0 -45.0)",
	"LINESTRING(-10.0 45.0,-110.0 45.0)",
	"LINESTRING(160.0 25.0,-160.0 25.0)",
	"LINESTRING(170.0 35.0,-160.0 35.0)",
	"LINESTRING(-10.0 35.0,10.0 -35.0)",
	"LINESTRING(-80.0 25.0,-60.0 -25.0)",
	"LINESTRING(-80.0 25.0,-60.0 -45.0)",
	"LINESTRING(-120.0 70.0,60.0 70.0)",
	"LINESTRING(-120.0 -70.0,60.0 -70.0)",
	"LINESTRING(-112.0 45.0,-112.00166666666666666666666666667 45.0)",
	"LINESTRING(-120.0 -5.0,60.0 80.0)",
	"LINESTRING(165.0 10.0,-172.0 -5.0)",
	"LINESTRING(97.87714324162704 46.6879465040995,155.49353589912155 -68.93911854796522)",
	"LINESTRING(-77.90029319006709 -20.61989357708765,-29.776541043747443 88.24497900223159)",
	"LINESTRING(12.21419896647646 -2.2758177391540926,149.7713684095024 13.210117902931728)",
	"LINESTRING(-49.891199414628915 66.72545480471234,-39.418865490450656 -89.97504625275525)",
	"POLYGON((-40.0 52.0, 102.0 -6.0, -67.0 -29.0, -40.0 52.0))",
};
